@@ -267,7 +267,10 @@ class StorageOracle(TransactionalStorageSPI):
 	# noinspection PyMethodMayBeStatic
 	def translate_straight_column_name(self, straight_column: EntityStraightColumn) -> Any:
 		if isinstance(straight_column, EntityStraightAggregateColumn):
-			if straight_column.arithmetic == EntityColumnAggregateArithmetic.SUM:
+			if straight_column.arithmetic == EntityColumnAggregateArithmetic.COUNT:
+				return func.count(straight_column.columnName) \
+					.label(self.get_alias_from_straight_column(straight_column))
+			elif straight_column.arithmetic == EntityColumnAggregateArithmetic.SUM:
 				return func.sum(straight_column.columnName).label(self.get_alias_from_straight_column(straight_column))
 			elif straight_column.arithmetic == EntityColumnAggregateArithmetic.AVG:
 				return func.avg(straight_column.columnName).label(self.get_alias_from_straight_column(straight_column))
@@ -326,7 +329,7 @@ class StorageOracle(TransactionalStorageSPI):
 	def execute_page_count(self, statement: SQLAlchemyStatement, page_size: int) -> Tuple[int, Optional[DataPage]]:
 		count = self.connection.execute(statement).scalar()
 
-		if count == 0:
+		if count is None or count == 0:
 			return 0, self.create_empty_page(page_size)
 		else:
 			return count, None
